summaryrefslogtreecommitdiffstats
path: root/sync/test
diff options
context:
space:
mode:
authormaxbogue <maxbogue@chromium.org>2015-09-09 02:13:18 -0700
committerCommit bot <commit-bot@chromium.org>2015-09-09 09:13:47 +0000
commit4824734c493af37e7602a27004bbc4a88aa04d6e (patch)
tree70a6d541c7e3aa8a27186c67e771db5986ecca1e /sync/test
parentffc4df78aec4cec783d52fc5a3390654e3d97dba (diff)
downloadchromium_src-4824734c493af37e7602a27004bbc4a88aa04d6e.zip
chromium_src-4824734c493af37e7602a27004bbc4a88aa04d6e.tar.gz
chromium_src-4824734c493af37e7602a27004bbc4a88aa04d6e.tar.bz2
[Sync] Use ModelTypeProcessor instead of ModelTypeProcessorImpl.
This CL doesn't touch ModelTypeProcessorImpl in DataTypeController because ModelTypeProcessor doesn't have the functionality for it. Those uses will be removed in a separate refactor. Also fixes a bunch of incorrect variable names. BUG=517953 Review URL: https://codereview.chromium.org/1321613003 Cr-Commit-Position: refs/heads/master@{#347880}
Diffstat (limited to 'sync/test')
-rw-r--r--sync/test/engine/injectable_sync_context_proxy.cc6
-rw-r--r--sync/test/engine/injectable_sync_context_proxy.h6
2 files changed, 6 insertions, 6 deletions
diff --git a/sync/test/engine/injectable_sync_context_proxy.cc b/sync/test/engine/injectable_sync_context_proxy.cc
index e3094e2..e194f26 100644
--- a/sync/test/engine/injectable_sync_context_proxy.cc
+++ b/sync/test/engine/injectable_sync_context_proxy.cc
@@ -21,16 +21,16 @@ void InjectableSyncContextProxy::ConnectTypeToSync(
syncer::ModelType type,
const DataTypeState& data_type_state,
const UpdateResponseDataList& response_list,
- const base::WeakPtr<ModelTypeProcessorImpl>& type_sync_proxy) {
+ const base::WeakPtr<ModelTypeProcessor>& type_processor) {
// This class is allowed to participate in only one connection.
DCHECK(!is_worker_connected_);
is_worker_connected_ = true;
// Hands off ownership of our member to the type_sync_proxy, while keeping
// an unsafe pointer to it. This is why we can only connect once.
scoped_ptr<CommitQueue> queue(queue_);
- type_sync_proxy->OnConnect(queue.Pass());
+ type_processor->OnConnect(queue.Pass());
}
void InjectableSyncContextProxy::Disconnect(syncer::ModelType type) {
@@ -21,16 +21,16 @@ void InjectableSyncContextProxy::ConnectTypeToSync(
DCHECK(!is_worker_connected_);
is_worker_connected_ = true;
- // Hands off ownership of our member to the type_sync_proxy, while keeping
+ // Hands off ownership of our member to the type_processor, while keeping
// an unsafe pointer to it. This is why we can only connect once.
scoped_ptr<CommitQueue> queue(queue_);
diff --git a/sync/test/engine/injectable_sync_context_proxy.h b/sync/test/engine/injectable_sync_context_proxy.h
index 4f19d9c..4ec38e66 100644
--- a/sync/test/engine/injectable_sync_context_proxy.h
+++ b/sync/test/engine/injectable_sync_context_proxy.h
@@ -11,11 +11,11 @@
namespace syncer_v2 {
-class ModelTypeProcessorImpl;
+class ModelTypeProcessor;
class CommitQueue;
// A SyncContextProxy implementation that, when a connection request is made,
// initalizes a connection to a previously injected ModelTypeProcessorImpl.
class InjectableSyncContextProxy : public SyncContextProxy {
public:
explicit InjectableSyncContextProxy(CommitQueue* queue);
@@ -25,7 +25,7 @@ class InjectableSyncContextProxy : public SyncContextProxy {
syncer::ModelType type,
const DataTypeState& data_type_state,
const UpdateResponseDataList& pending_updates,
- const base::WeakPtr<ModelTypeProcessorImpl>& type_sync_proxy) override;
+ const base::WeakPtr<ModelTypeProcessor>& type_processor) override;
void Disconnect(syncer::ModelType type) override;
scoped_ptr<SyncContextProxy> Clone() const override;
@@ -11,11 +11,11 @@
class CommitQueue;
// A SyncContextProxy implementation that, when a connection request is made,
-// initalizes a connection to a previously injected ModelTypeProcessorImpl.
+// initalizes a connection to a previously injected ModelTypeProcessor.
class InjectableSyncContextProxy : public SyncContextProxy {
public: